==> haskell-base-orphans-0.8.8.2-13.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-orphans
version:              0.8.8.2
visibility:           public
id:                   base-orphans-0.8.8.2-9SrFWHJupRo443OOwuTGTo
key:                  base-orphans-0.8.8.2-9SrFWHJupRo443OOwuTGTo
license:              MIT
copyright:
    (c) 2012-2017 Simon Hengel,
    (c) 2014-2017 João Cristóvão,
    (c) 2015-2017 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

homepage:             https://github.com/haskell-compat/base-orphans#readme
synopsis:             Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in
    later versions of @base@ to a wider (older) range of compilers.
    @base-orphans@ does not export anything except the orphan instances
    themselves and complements @<http://hackage.haskell.org/package/base-compat
    base-compat>@.

    See the README for what instances are covered:
    <https://github.com/haskell-compat/base-orphans#readme>.
    See also the
    <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered>
    section.

category:             Compatibility
abi:                  773a6f692b35f716bd500b36788e1cdd
exposed:              True
exposed-modules:      Data.Orphans
hidden-modules:       Data.Orphans.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/base-orphans-0.8.8.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/base-orphans-0.8.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-orphans
hs-libraries:         HSbase-orphans-0.8.8.2-9SrFWHJupRo443OOwuTGTo
depends:              base-4.16.4.0 ghc-prim-0.8.0
haddock-interfaces:
    /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock

haddock-html:         /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.8.8.2-17.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-orphans
version:              0.8.8.2
visibility:           public
id:                   base-orphans-0.8.8.2-8pE3LNPkijIA21wki8CJLW
key:                  base-orphans-0.8.8.2-8pE3LNPkijIA21wki8CJLW
license:              MIT
copyright:
    (c) 2012-2017 Simon Hengel,
    (c) 2014-2017 João Cristóvão,
    (c) 2015-2017 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

homepage:             https://github.com/haskell-compat/base-orphans#readme
synopsis:             Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in
    later versions of @base@ to a wider (older) range of compilers.
    @base-orphans@ does not export anything except the orphan instances
    themselves and complements @<http://hackage.haskell.org/package/base-compat
    base-compat>@.

    See the README for what instances are covered:
    <https://github.com/haskell-compat/base-orphans#readme>.
    See also the
    <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered>
    section.

category:             Compatibility
abi:                  2dd5125ba9cfad1607ec7cf7ddf58ec8
exposed:              True
exposed-modules:      Data.Orphans
hidden-modules:       Data.Orphans.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/base-orphans-0.8.8.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/base-orphans-0.8.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-orphans
hs-libraries:         HSbase-orphans-0.8.8.2-8pE3LNPkijIA21wki8CJLW
depends:              base-4.16.4.0 ghc-prim-0.8.0
haddock-interfaces:
    /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock

haddock-html:         /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
